@@ -1,24 +1,25 @@
 use std::ops::{Deref, Range};
-use std::sync::LazyLock;
 
 use anyhow::{Context, Result};
 use github_actions_models::action;
 use github_actions_models::workflow::job::StepBody;
-use regex::Regex;
 use tree_sitter::{
     Language, Parser, QueryCapture, QueryCursor, QueryMatches, StreamingIterator as _, Tree,
 };
 
 use super::{Audit, AuditLoadError, audit_meta};
+use crate::config::Config;
 use crate::finding::location::Locatable as _;
 use crate::finding::{Confidence, Finding, Severity};
 use crate::models::{workflow::JobExt as _, workflow::Step};
 use crate::state::AuditState;
 use crate::utils;
+use crate::utils::once::static_regex;
 
-static GITHUB_ENV_WRITE_CMD: LazyLock<Regex> = LazyLock::new(|| {
-    Regex::new(r#"(?mi)^.+\s*>>?\s*"?%(?<destination>GITHUB_ENV|GITHUB_PATH)%"?.*$"#).unwrap()
-});
+static_regex!(
+    GITHUB_ENV_WRITE_CMD,
+    r#"(?mi)^.+\s*>>?\s*"?%(?<destination>GITHUB_ENV|GITHUB_PATH)%"?.*$"#
+);
 
 pub(crate) struct GitHubEnv {
     bash: Language,
@@ -167,18 +168,24 @@ impl GitHubEnv {
         let cmd = self
             .bash_redirect_query
             .capture_index_for_name("cmd")
-            .unwrap();
+            .expect("internal error: missing capture index for 'cmd'");
         let args = self
             .bash_redirect_query
             .capture_index_for_name("args")
-            .unwrap();
+            .expect("internal error: missing capture index for 'args'");
 
         let mut matching_spans = vec![];
 
         matches.for_each(|mat| {
             let cmd = {
-                let cap = mat.captures.iter().find(|cap| cap.index == cmd).unwrap();
-                cap.node.utf8_text(script_body.as_bytes()).unwrap()
+                let cap = mat
+                    .captures
+                    .iter()
+                    .find(|cap| cap.index == cmd)
+                    .expect("internal error: expected capture for cmd");
+                cap.node
+                    .utf8_text(script_body.as_bytes())
+                    .expect("impossible: capture should be UTF-8 by construction")
             };
 
             let args = mat.captures.iter().filter(|cap| cap.index == args);
@@ -190,15 +197,17 @@ impl GitHubEnv {
                     .captures
                     .iter()
                     .find(|cap| cap.index == self.bash_redirect_query.span_idx)
-                    .unwrap();
+                    .expect("internal error: expected capture for span");
 
                 let destination = {
                     let cap = mat
                         .captures
                         .iter()
                         .find(|cap| cap.index == self.bash_redirect_query.destination_idx)
-                        .unwrap();
-                    cap.node.utf8_text(script_body.as_bytes()).unwrap()
+                        .expect("internal error: expected capture for destination");
+                    cap.node
+                        .utf8_text(script_body.as_bytes())
+                        .expect("impossible: capture should be UTF-8 by construction")
                 };
                 matching_spans.push((destination, span.node.byte_range()));
             }
@@ -217,15 +226,17 @@ impl GitHubEnv {
                     .captures
                     .iter()
                     .find(|cap| cap.index == query.span_idx)
-                    .unwrap();
+                    .expect("internal error: expected capture for span");
 
                 let destination = {
                     let cap = mat
                         .captures
                         .iter()
                         .find(|cap| cap.index == query.destination_idx)
-                        .unwrap();
-                    cap.node.utf8_text(script_body.as_bytes()).unwrap()
+                        .expect("internal error: expected capture for destination");
+                    cap.node
+                        .utf8_text(script_body.as_bytes())
+                        .expect("impossible: capture should be UTF-8 by construction")
                 };
 
                 matching_spans.push((destination, span.node.byte_range()));
@@ -239,10 +250,11 @@ impl GitHubEnv {
         GITHUB_ENV_WRITE_CMD
             .captures_iter(script_body)
             .map(|c| {
-                let name = c.name("destination").unwrap().as_str();
-                let span = c.name("destination").unwrap().range();
+                let dest = c
+                    .name("destination")
+                    .expect("internal error: capture with missing destination");
 
-                (name, span)
+                (dest.as_str(), dest.range())
             })
             .collect()
     }
@@ -271,15 +283,17 @@ impl GitHubEnv {
                     .captures
                     .iter()
                     .find(|cap| cap.index == query.span_idx)
-                    .unwrap();
+                    .expect("internal error: no matching capture");
 
                 let destination = {
                     let cap = mat
                         .captures
                         .iter()
                         .find(|cap| cap.index == query.destination_idx)
-                        .unwrap();
-                    cap.node.utf8_text(script_body.as_bytes()).unwrap()
+                        .expect("internal error: no matching capture");
+                    cap.node
+                        .utf8_text(script_body.as_bytes())
+                        .expect("impossible: capture should be UTF-8 by construction")
                 };
 
                 matching_spans.push((destination, span.node.byte_range()));
@@ -316,7 +330,7 @@ impl GitHubEnv {
 }
 
 impl Audit for GitHubEnv {
-    fn new(_state: &AuditState<'_>) -> Result<Self, AuditLoadError>
+    fn new(_state: &AuditState) -> Result<Self, AuditLoadError>
     where
         Self: Sized,
     {
@@ -344,7 +358,11 @@ impl Audit for GitHubEnv {
         })
     }
 
-    fn audit_step<'doc>(&self, step: &Step<'doc>) -> anyhow::Result<Vec<Finding<'doc>>> {
+    fn audit_step<'doc>(
+        &self,
+        step: &Step<'doc>,
+        _config: &Config,
+    ) -> anyhow::Result<Vec<Finding<'doc>>> {
         let mut findings = vec![];
 
         let workflow = step.workflow();
@@ -395,6 +413,7 @@ impl Audit for GitHubEnv {
     fn audit_composite_step<'doc>(
         &self,
         step: &super::CompositeStep<'doc>,
+        _config: &Config,
     ) -> Result<Vec<Finding<'doc>>> {
         let mut findings = vec![];
 
@@ -426,7 +445,6 @@ impl Audit for GitHubEnv {
 mod tests {
     use crate::audit::Audit;
     use crate::audit::github_env::{GITHUB_ENV_WRITE_CMD, GitHubEnv};
-    use crate::github_api::GitHubHost;
     use crate::state::AuditState;
 
     #[test]
@@ -491,12 +509,7 @@ mod tests {
             ("echo 'completely-static' \"foo\" >> $GITHUB_ENV", false), // LHS is completely static
             ("echo \"completely-static\" >> $GITHUB_ENV", false), // LHS is completely static
         ] {
-            let audit_state = AuditState {
-                config: &Default::default(),
-                no_online_audits: false,
-                gh_client: None,
-                gh_hostname: GitHubHost::Standard("github.com".into()),
-            };
+            let audit_state = AuditState::default();
 
             let sut = GitHubEnv::new(&audit_state).expect("failed to create audit");
 
@@ -607,12 +620,7 @@ mod tests {
                 false,
             ), // GITHUB_ENV is not a variable
         ] {
-            let audit_state = AuditState {
-                config: &Default::default(),
-                no_online_audits: false,
-                gh_client: None,
-                gh_hostname: GitHubHost::Standard("github.com".into()),
-            };
+            let audit_state = AuditState::default();
 
             let sut = GitHubEnv::new(&audit_state).expect("failed to create audit");
 
