@@ -15,7 +15,7 @@ use clap_complete::Generator;
 use clap_verbosity_flag::InfoLevel;
 use etcetera::AppStrategy as _;
 use finding::{Confidence, Persona, Severity};
-use github_api::{GitHubHost, GitHubToken};
+use github::{GitHubHost, GitHubToken};
 use indicatif::ProgressStyle;
 use owo_colors::OwoColorize;
 use registry::input::{InputKey, InputRegistry};
@@ -29,14 +29,16 @@ use tracing_subscriber::{EnvFilter, layer::SubscriberExt as _, util::SubscriberI
 
 use crate::{
     config::{Config, ConfigError, ConfigErrorInner},
-    github_api::Client,
+    github::Client,
+    models::AsDocument,
     registry::input::CollectionError,
+    utils::once::warn_once,
 };
 
 mod audit;
 mod config;
 mod finding;
-mod github_api;
+mod github;
 #[cfg(feature = "lsp")]
 mod lsp;
 mod models;
@@ -46,7 +48,7 @@ mod state;
 mod utils;
 
 #[cfg(all(
-    not(target_env = "msvc"),
+    not(target_family = "windows"),
     any(
         target_arch = "x86_64",
         target_arch = "aarch64",
@@ -554,7 +556,7 @@ enum Error {
     Lsp(#[from] lsp::Error),
     /// An error from the GitHub API client.
     #[error(transparent)]
-    Client(#[from] github_api::ClientError),
+    Client(#[from] github::ClientError),
     /// An error while loading audit rules.
     #[error("failed to load audit rules")]
     AuditLoad(#[source] anyhow::Error),
@@ -725,13 +727,22 @@ fn run(app: &mut App) -> Result<ExitCode, Error> {
         let span = info_span!("audit");
         span.pb_set_length((registry.len() * audit_registry.len()) as u64);
         span.pb_set_style(
-            &ProgressStyle::with_template("[{elapsed_precise}] {bar:!30.cyan/blue} {msg}").unwrap(),
+            &ProgressStyle::with_template("[{elapsed_precise}] {bar:!30.cyan/blue} {msg}")
+                .expect("couldn't set progress bar style"),
         );
 
         let _guard = span.enter();
 
         for (input_key, input) in registry.iter_inputs() {
             Span::current().pb_set_message(input.key().filename());
+
+            if input.as_document().has_anchors() {
+                warn_once!(
+                    "one or more inputs contains YAML anchors; you may encounter crashes or unpredictable behavior"
+                );
+                warn_once!("for more information, see: https://docs.zizmor.sh/usage/#yaml-anchors");
+            }
+
             let config = registry.get_config(input_key.group());
             for (ident, audit) in audit_registry.iter_audits() {
                 tracing::debug!("running {ident} on {input}", input = input.key());
@@ -769,19 +780,49 @@ fn run(app: &mut App) -> Result<ExitCode, Error> {
         }
     };
 
-    if let Some(fix_mode) = app.fix {
-        output::fix::apply_fixes(fix_mode, &results, &registry).map_err(Error::Fix)?;
-    }
+    let all_fixed = if let Some(fix_mode) = app.fix {
+        let fix_result =
+            output::fix::apply_fixes(fix_mode, &results, &registry).map_err(Error::Fix)?;
+
+        // If all findings have applicable fixes and all were successfully applied,
+        // we should exit with success.
+        results.all_findings_have_applicable_fixes(fix_mode)
+            && fix_result.failed_count == 0
+            && fix_result.applied_count > 0
+    } else {
+        false
+    };
 
     if app.no_exit_codes || matches!(app.format, OutputFormat::Sarif) {
         Ok(ExitCode::SUCCESS)
+    } else if all_fixed {
+        // All findings were auto-fixed, no manual intervention needed
+        Ok(ExitCode::SUCCESS)
     } else {
         Ok(results.exit_code())
     }
 }
 
 fn main() -> ExitCode {
-    human_panic::setup_panic!();
+    // NOTE: We only use human-panic on non-CI environments.
+    // This is because human-panic's output gets sent to a temporary file,
+    // which is then typically inaccessible from an already failed
+    // CI job. In those cases, it's better to dump directly to stderr,
+    // since that'll typically be captured by console logging.
+    if std::env::var_os("CI").is_some() {
+        std::panic::set_hook(Box::new(|info| {
+            let trace = std::backtrace::Backtrace::force_capture();
+            eprintln!("FATAL: zizmor crashed. This is a bug that should be reported.");
+            eprintln!(
+                "Please report to: {repo}",
+                repo = env!("CARGO_PKG_REPOSITORY")
+            );
+            eprintln!("Panic information:\n{}", info);
+            eprintln!("Backtrace:\n{}", trace);
+        }));
+    } else {
+        human_panic::setup_panic!();
+    }
 
     let mut app = App::parse();
 
@@ -827,55 +868,57 @@ fn main() -> ExitCode {
 
                     Some(report)
                 }
-                Error::Collection(err @ CollectionError::InvalidInput(..)) => {
-                    let group = Group::with_title(Level::ERROR.primary_title(err.to_string()))
-                        .element(Level::HELP.message(format!(
-                            "valid inputs are files, directories, or GitHub {slug} slugs",
-                            slug = "user/repo[@ref]".green()
-                        )))
-                        .element(Level::HELP.message(format!(
-                            "examples: {ex1}, {ex2}, {ex3}, or {ex4}",
-                            ex1 = "path/to/workflow.yml".green(),
-                            ex2 = ".github/".green(),
-                            ex3 = "example/example".green(),
-                            ex4 = "example/example@v1.2.3".green()
-                        )));
+                Error::Collection(err) => match err.inner() {
+                    CollectionError::DuplicateInput(..) => {
+                        let group = Group::with_title(Level::ERROR.primary_title(err.to_string()))
+                            .element(Level::HELP.message(format!(
+                                "valid inputs are files, directories, or GitHub {slug} slugs",
+                                slug = "user/repo[@ref]".green()
+                            )))
+                            .element(Level::HELP.message(format!(
+                                "examples: {ex1}, {ex2}, {ex3}, or {ex4}",
+                                ex1 = "path/to/workflow.yml".green(),
+                                ex2 = ".github/".green(),
+                                ex3 = "example/example".green(),
+                                ex4 = "example/example@v1.2.3".green()
+                            )));
 
-                    let renderer = Renderer::styled();
-                    let report = renderer.render(&[group]);
+                        let renderer = Renderer::styled();
+                        let report = renderer.render(&[group]);
 
-                    Some(report)
-                }
-                Error::Collection(err @ CollectionError::NoGitHubClient(_)) => {
-                    let mut group = Group::with_title(Level::ERROR.primary_title(err.to_string()));
-
-                    if app.offline {
-                        group = group
-                            .elements([Level::HELP
-                                .message("remove --offline to audit remote repositories")]);
-                    } else if app.gh_token.is_none() {
-                        group = group
-                            .elements([Level::HELP
-                                .message("set a GitHub token with --gh-token or GH_TOKEN")]);
+                        Some(report)
                     }
+                    CollectionError::NoGitHubClient(..) => {
+                        let mut group =
+                            Group::with_title(Level::ERROR.primary_title(err.to_string()));
 
-                    let renderer = Renderer::styled();
-                    let report = renderer.render(&[group]);
+                        if app.offline {
+                            group = group.elements([Level::HELP
+                                .message("remove --offline to audit remote repositories")]);
+                        } else if app.gh_token.is_none() {
+                            group = group.elements([Level::HELP
+                                .message("set a GitHub token with --gh-token or GH_TOKEN")]);
+                        }
 
-                    Some(report)
-                }
-                Error::Collection(err @ CollectionError::Yamlpath(_)) => {
-                    let group = Group::with_title(Level::ERROR.primary_title(err.to_string())).elements([
-                        Level::HELP.message("this typically indicates a bug in zizmor; please report it"),
-                        Level::HELP.message(
-                            "https://github.com/zizmorcore/zizmor/issues/new?template=bug-report.yml",
-                        ),
-                    ]);
-                    let renderer = Renderer::styled();
-                    let report = renderer.render(&[group]);
+                        let renderer = Renderer::styled();
+                        let report = renderer.render(&[group]);
 
-                    Some(report)
-                }
+                        Some(report)
+                    }
+                    CollectionError::Yamlpath(..) => {
+                        let group = Group::with_title(Level::ERROR.primary_title(err.to_string())).elements([
+                            Level::HELP.message("this typically indicates a bug in zizmor; please report it"),
+                            Level::HELP.message(
+                                "https://github.com/zizmorcore/zizmor/issues/new?template=bug-report.yml",
+                            ),
+                        ]);
+                        let renderer = Renderer::styled();
+                        let report = renderer.render(&[group]);
+
+                        Some(report)
+                    }
+                    _ => None,
+                },
                 _ => None,
             };
 
